@@ -1,23 +1,29 @@
-/// Assert two values are not equal.
+/// Assert a value is not equal to another.
 ///
-/// * When true, return `Ok(true)`.
+/// * When true, return `Ok(())`.
 ///
 /// * When false, call [`panic!`] with a message and the values of the
 ///   expressions with their debug representations.
 ///
-/// # Example
+/// # Examples
 ///
 /// ```rust
-/// # #[macro_use] extern crate assertables; fn main() {
+/// # #[macro_use] extern crate assertables;
+/// # use std::panic;
+/// # fn main() {
 /// assert_ne!(1, 2);
 /// //-> ()
-/// # }
-/// ```
 ///
-/// ```rust
-/// # #[macro_use] extern crate assertables; fn main() {
-/// // assert_ne!(1, 1);
-/// //-> panic!("assertion failed: `(left != right)`\n  left: `1`,\n right: `1`")
+/// # let result = panic::catch_unwind(|| {
+/// assert_ne!(1, 1);
+/// //-> panic!
+/// // assertion failed: `(left != right)`
+/// //   left: `1`,
+/// //  right: `1`
+/// # });
+/// # let actual = result.unwrap_err().downcast::<String>().unwrap().to_string();
+/// # let expect = "assertion failed: `(left != right)`\n  left: `1`,\n right: `1`";
+/// # assert_eq!(actual, expect);
 /// # }
 /// ```
 ///
@@ -33,10 +39,7 @@ mod tests {
         let a = 1;
         let b = 2;
         let x = assert_ne!(a, b);
-        assert_eq!(
-            x,
-            ()
-        );
+        assert_eq!(x, ());
     }
 
     #[test]
@@ -52,10 +55,7 @@ mod tests {
         let a = 1;
         let b = 2;
         let x = assert_ne!(a, b, "message");
-        assert_eq!(
-            x,
-            ()
-        );
+        assert_eq!(x, ());
     }
 
     #[test]
